sqltriples.Subjects

Module sqltriples :: Class Subjects |
[show private | hide private]
[frames | no frames]

## Class Subjects

      Results --+
                |
    SingleResults --+
                    |
                   Subjects

A class representing a selection of subjects.

Method Summary
| ``get_query`(self, index, constraints)` Produce for 'index' something like this:
| ``get_subquery`(self, parent_index, index)` Produce for 'index' something like this: exists (select ...
Inherited from Results
| ``__init__`(self, store, pattern, fn, ordering, limit)` Initialise the results object with the given 'store', 'pattern', optional 'ordering' description and optional 'limit' criteria.
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``get_child_query`(self, index)` Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query.

Method Details

### get_query(self, index, constraints=None) Produce for 'index' something like this: select ... from triples as triples_i0 where ...

### get_subquery(self, parent_index, index)
    Produce for 'index' something like this:

    exists (select ... from triples as triples_i1 where ...
            and triples_i0.subject = triples_i1.subject ...)

Generated by Epydoc 2.1 on Tue Mar 21 02:02:07 2006 | http://epydoc.sf.net